---
title: "PCI DSS v4.0"
description: "Terraform compliance scanning for PCI DSS v4.0 — assess for free, remediate with ComplyForm"
---

import { Badge } from '@astrojs/starlight/components';

<Badge text="Pro" variant="note" />
<Badge text="Financial" variant="tip" />

**Issuing body:** [PCI SSC](https://www.pcisecuritystandards.org)
**Jurisdiction:** Global — Global
**Countries:** Worldwide


## Assessment

Assess your infrastructure against PCI DSS for free at any tier:

```bash
complyform assess --frameworks=pci_dss
```

## Remediation

Requires Pro tier or higher ($599/yr) for remediation.

```bash
complyform remediate --frameworks=pci_dss
```

## Related Frameworks

- [SOC 2 Type II](/frameworks/soc2)
- [CIS GCP v2.0](/frameworks/cis_gcp)
- [CIS Azure v2.0](/frameworks/cis_azure)
- [CIS AWS v3.0](/frameworks/cis_aws)
